S class

Constructors

S()

Properties

accept String
accept
no setter
answerOnOtherDevice String
The other client has answered the call
no setter
applyForCameraPermission String
apply for camera permission
no setter
applyForMicrophoneAndCameraPermissions String
apply for microphone and camera permissions
no setter
applyForMicrophonePermission String
apply for microphone permission
no setter
blurBackground String
blurBackground
no setter
callFailedUserIdEmpty String
Call failed, userId is empty
no setter
cameraIsOff String
cameraIsOff
no setter
cameraIsOn String
cameraIsOn
no setter
displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions String
display popUpWindow while running in the background and display popUpWindow permissions
no setter
errorInPeerBlacklist String
error in peer blacklist
no setter
groupCallCameraOff String
Camera Off
no setter
groupCallCameraOn String
Camera On
no setter
groupCallConnecting String
Connecting...
no setter
groupCallCreateFailed String
Create group call failed
no setter
groupCallDuration String
Duration
no setter
groupCallEnded String
Group call ended
no setter
groupCallIgnore String
Ignore
no setter
groupCallInitFailed String
Group call init failed
no setter
groupCallInProgress String
In Call
no setter
groupCallInvitation String
Group Call Invitation
no setter
groupCallInvite String
Invite
no setter
groupCallInviteMore String
Invite More
no setter
groupCallInviteYouToJoin String
invites you to join group call
no setter
groupCallJoinFailed String
Join group call failed
no setter
groupCallJoining String
Joining...
no setter
groupCallMemberJoined String
Joined
no setter
groupCallMemberLeft String
Left
no setter
groupCallMembersFull String
Group call is full
no setter
groupCallMicOff String
Mic Off
no setter
groupCallMicOn String
Mic On
no setter
groupCallMinimize String
Minimize
no setter
groupCallMuted String
Muted
no setter
groupCallNetworkError String
Network error, please try again
no setter
groupCallNoVideo String
Video not enabled
no setter
groupCallSpeakerOff String
Speaker Off
no setter
groupCallSpeakerOn String
Speaker On
no setter
groupCallSpeaking String
Speaking
no setter
groupCallSwitchCamera String
Switch Camera
no setter
groupCallToggleCamera String
Camera
no setter
groupCallToggleMic String
Microphone
no setter
groupCallToggleSpeaker String
Speaker
no setter
groupCallWaiting String
Waiting
no setter
hangUp String
hangUp
no setter
hashCode int
The hash code for this object.
no setterinherited
initEngineFail String
Init engine failed
no setter
insufficientPermissions String
insufficient permissions
no setter
microphoneIsOff String
microphoneIsOff
no setter
microphoneIsOn String
microphoneIsOn
no setter
needBackgroundStartPermission String
Your phone has not granted background start permission, minimizing calls may not work properly
no setter
needFloatWindowPermission String
need float window permission
no setter
needToAccessCameraPermission String
need to access camera permission
no setter
needToAccessMicrophoneAndCameraPermissions String
need to access microphone and camera permissions
no setter
needToAccessMicrophonePermission String
need to access microphone permission
no setter
noBackgroundStartPermission String
no background start permission
no setter
noFloatWindowPermission String
no float window permission
no setter
permissionResultFail String
Permission result fail
no setter
rejectOnOtherDevice String
The other client has rejected the call
no setter
remoteCancel String
The call was canceled
no setter
remoteTimeout String
Timeout and no response
no setter
remoteUserReject String
remote user rejected
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerIsOff String
speakerIsOff
no setter
speakerIsOn String
speakerIsOn
no setter
startCameraPermissionDenied String
Start camera permission denied.
no setter
switchCamera String
switchCamera
no setter
userBusy String
Other party is busy
no setter
userInCall String
User is already in a call
no setter
waiting String
waiting
no setter
youHaveANewCall String
You have a new call
no setter

Methods

groupCallOtherMembers(Object count) String
and {count} others
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

current S
no setter

Static Methods

load(Locale locale) Future<S>
maybeOf(BuildContext context) S?
of(BuildContext context) S

Constants

delegate → const AppLocalizationDelegate