CallKitClientLocalizations class abstract

Callers can lookup localized strings with an instance of CallKitClientLocalizations returned by CallKitClientLocalizations.of(context).

Applications need to include CallKitClientLocalizations.delegate() in their app's localizationDelegates list, and the locales they support in the app's supportedLocales list. For example:

import 'call_ui_localization/call_ui_localizations.dart';

return MaterialApp(
  localizationsDelegates: CallKitClientLocalizations.localizationsDelegates,
  supportedLocales: CallKitClientLocalizations.supportedLocales,
  home: MyApplicationHome(),
);

Update pubspec.yaml

Please make sure to update your pubspec.yaml to include the following packages:

dependencies:
  # Internationalization support.
  flutter_localizations:
    sdk: flutter
  intl: any # Use the pinned version from flutter_localizations

  # Rest of dependencies

iOS Applications

iOS applications define key application metadata, including supported locales, in an Info.plist file that is built into the application bundle. To configure the locales supported by your app, you’ll need to edit this file.

First, open your project’s ios/Runner.xcworkspace Xcode workspace file. Then, in the Project Navigator, open the Info.plist file under the Runner project’s Runner folder.

Next, select the Information Property List item, select Add Item from the Editor menu, then select Localizations from the pop-up menu.

Select and expand the newly-created Localizations item then, for each locale your application supports, add a new item and select the locale you wish to add from the pop-up menu in the Value field. This list should be consistent with the languages listed in the CallKitClientLocalizations.supportedLocales property.

Implementers

Constructors

CallKitClientLocalizations(String locale)

Properties

accept String
No description provided for @accept.
no setter
answerOnOtherDevice String
No description provided for @answerOnOtherDevice.
no setter
applyForMicrophoneAndCameraPermissions String
No description provided for @applyForMicrophoneAndCameraPermissions.
no setter
applyForMicrophonePermission String
No description provided for @applyForMicrophonePermission.
no setter
blurBackground String
No description provided for @blurBackground.
no setter
callFailedUserIdEmpty String
No description provided for @callFailedUserIdEmpty.
no setter
cameraIsOff String
No description provided for @cameraIsOff.
no setter
cameraIsOn String
No description provided for @cameraIsOn.
no setter
displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions String
No description provided for @displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions.
no setter
errorInPeerBlacklist String
No description provided for @errorInPeerBlacklist.
no setter
hangUp String
No description provided for @hangUp.
no setter
hashCode int
The hash code for this object.
no setterinherited
initEngineFail String
No description provided for @initEngineFail.
no setter
insufficientPermissions String
No description provided for @insufficientPermissions.
no setter
localeName String
final
microphoneIsOff String
No description provided for @microphoneIsOff.
no setter
microphoneIsOn String
No description provided for @microphoneIsOn.
no setter
needBackgroundStartPermission String
No description provided for @needBackgroundStartPermission.
no setter
needFloatWindowPermission String
No description provided for @needFloatWindowPermission.
no setter
needToAccessMicrophoneAndCameraPermissions String
No description provided for @needToAccessMicrophoneAndCameraPermissions.
no setter
needToAccessMicrophonePermission String
No description provided for @needToAccessMicrophonePermission.
no setter
noBackgroundStartPermission String
No description provided for @noBackgroundStartPermission.
no setter
noFloatWindowPermission String
No description provided for @noFloatWindowPermission.
no setter
permissionResultFail String
No description provided for @permissionResultFail.
no setter
rejectOnOtherDevice String
No description provided for @rejectOnOtherDevice.
no setter
remoteCancel String
No description provided for @remoteCancel.
no setter
remoteTimeout String
No description provided for @remoteTimeout.
no setter
remoteUserReject String
No description provided for @remoteUserReject.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerIsOff String
No description provided for @speakerIsOff.
no setter
speakerIsOn String
No description provided for @speakerIsOn.
no setter
startCameraPermissionDenied String
No description provided for @startCameraPermissionDenied.
no setter
switchCamera String
No description provided for @switchCamera.
no setter
userBusy String
No description provided for @userBusy.
no setter
userInCall String
No description provided for @userInCall.
no setter
waiting String
No description provided for @waiting.
no setter
youHaveANewCall String
No description provided for @youHaveANewCall.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) CallKitClientLocalizations?

Constants

delegate → const LocalizationsDelegate<CallKitClientLocalizations>
localizationsDelegates → const List<LocalizationsDelegate>
A list of this localizations delegate along with the default localizations delegates.
supportedLocales → const List<Locale>
A list of this localizations delegate's supported locales.