ne_callkit_ui library
Classes
- CallConfig
- CallEndInfo
- CallInfo
- CallKitApi
- CallKitEventSink
- CallKitUILog
- CallkitVideoRendererApi
- CallManager
- CallObserverExtraInfo
- CallParam
- CallPushConfig
- CallResponse
- CallState
- CallTypeChangeInfo
- GroupAcceptResponse
- 接听群呼响应
- GroupCallKitApi
- GroupCallKitEventSink
- 群呼业务回调
- GroupCallResponse
- 发起群呼响应
- GroupJoinResponse
- 加入群呼响应
- GroupMediaEventSink
- 媒体事件回调
- GroupQueryCallInfoResponse
- 查询群呼信息响应
- GroupQueryMembersResponse
- 查询成员列表响应
- GroupSimpleResponse
- 群呼简单响应
- HangupParam
- InviteInfo
- LCKConfig
- NEASRCaptionConfig
- Configuration for ASR (speech-to-text) captions.
- NEAsrCaptionResult
- Result of a single ASR caption recognition segment.
- NEAudioVolumeInfo
- 音量信息
- NECallConfig
- Configuration describing call behavior and capabilities.
- NECallDefine
- NECallEndInfo
- Information describing why and how a call ended.
- NECallEngine
- Primary CallKit engine entry point exposed to Flutter.
- NECallEngineDelegate
- Callback listener container for call-related events.
- NECallError
- Collection of error codes that can occur during calls.
- NECallInfo
- High-level information describing the current call.
- NECallkitDefaultRendererController
- 默认渲染器控制器
- NECallkitTextureView
- 基于 Texture 的视频视图
- NECallKitUI
- NECallkitVideoRenderer
- 视频渲染器接口
- NECallkitVideoRendererController
- 视频渲染器控制器接口
- NECallkitVideoRendererFactory
- 视频渲染器工厂
- NECallkitVideoValue
- 视频帧值,包含宽高和旋转角度
- NECallkitVideoView
- Widget used to render CallKit video.
- NECallkitVideoViewState
- State implementation for NECallkitVideoView.
- NECallObserver
- The NECallObserver class. NECallObserver is used to observe NECallEngine event that you are interested in.
- NECallParam
- Parameters used when placing a call.
- NECallParams
- NECallPushConfig
- Push notification configuration for call invites.
- NECallRecentCallsFilter
- NECallRecords
- NECallTimeoutPolicy
- Shared public timeout contract for single-call engines.
- NECallTypeChangeInfo
- Information describing a call type change event.
- NECertificateConfig
- 证书配置参数
- NEDesktopAudioDevice
- Desktop audio device descriptor exposed by the desktop bridge.
- NEDesktopVideoDevice
- Desktop video capture device descriptor exposed by the desktop bridge.
- NEExtraConfig
- 额外配置参数
- NEGroupAcceptParam
- 接听群呼参数
- NEGroupAcceptResult
- 接听群呼结果
- NEGroupCallEndEvent
- 群呼结束事件
- NEGroupCallEngine
- 群呼引擎接口
- NEGroupCallEngineDelegate
- 群呼业务回调代理
- NEGroupCallGroupType
- 群组类型常量
- NEGroupCallHangupEvent
- 成员挂断事件
- NEGroupCallInfo
- 群呼信息
- NEGroupCallMember
- 群呼成员信息
- NEGroupCallParam
- 发起群呼参数
- NEGroupCallResult
- 发起群呼结果
- NEGroupCallState
- 群呼状态常量
- NEGroupConfigParam
- 群呼引擎配置参数
- NEGroupErrorCode
- 错误码常量
- NEGroupHangupParam
- 挂断群呼参数
- NEGroupHangupReason
- 挂断原因常量
- NEGroupHangupResult
- 挂断群呼结果
- NEGroupInviteMode
- 邀请模式常量
- NEGroupInviteParam
- 邀请成员参数
- NEGroupInviteResult
- 邀请成员结果
- NEGroupJoinMode
- 加入模式常量
- NEGroupJoinParam
- 主动加入参数
- NEGroupJoinResult
- 加入群呼结果
- NEGroupMediaDelegate
- 媒体事件回调代理
- NEGroupMediaResult
- 媒体操作结果(仅包含 code 和 msg)
- NEGroupPushMode
- 推送模式常量
- NEGroupPushParam
- 推送配置参数
- NEGroupQueryCallInfoResult
- 查询群呼信息结果
- NEGroupQueryMembersResult
- 查询成员列表结果
- NEGroupResult
- 群呼通用结果
- NEGroupRtcSafeMode
- RTC 安全模式常量
- NEGroupUserAction
- 用户动作常量
- NEGroupUserState
- 用户状态常量
- NEGroupViewParam
- 群呼视图设置参数
- NEHangupParam
- Parameters used when hanging up a call.
- NEInviteInfo
- Invite information for an incoming call.
- NELCKAcceptResult
- Result of a Live Communication Kit accept action.
- NELCKConfig
- Configuration for Live Communication Kit integration.
- NELCKHangupResult
- Result of a Live Communication Kit hangup action.
- NENetworkQualityInfo
- network quality info
- NERecordConfig
- Configuration for a call record entry.
- NERecordProvider
- Provider interface for custom call record sending.
- NEResult
- Generic function return type
- NERtcASRCaptionConfig
- NERtcAsrCaptionResult
- NERtcInfo
- RTC information for the call, including channel and user IDs.
- NESetupConfig
- Configuration used when setting up the CallKit engine.
- NESignalInfo
- Call-related signaling information.
- NESwitchParam
- Parameters used when switching the call type.
- NEUserInfo
- Basic user information associated with a call.
- NEValueCallback
- NEVideoRendererCache
- 通用视频渲染器缓存管理(单例)
- NEViewParam
- Parameters that describe a platform view used to render video.
- RecordConfig
- RtcInfo
- SetupConfig
- SignalInfo
- SimpleResponse
- Basic response model used by the CallKit API.
- SwitchParam
- UserInfo
- ViewParam
Enums
- CallEndReason
- CallEngineStatus
- CallInitRtcMode
- CallPage
- CallSwitchState
- CallTerminalCode
- CallType
- NEAudioPlaybackDevice
- NECallEngineStatus
- Overall status of the call engine.
- NECallInitRtcMode
- Defines how the RTC engine should be initialized for calls.
- NECallResultType
- NECallRole
- Indicates the role in the calls.
- NECallScene
- Indicates the call scene, including 1v1 calls, group calls etc.
- NECallStatus
- Indicates the calls status
- NECallSwitchState
- State of switching between call types (audio/video).
- NECallTerminalCode
- Reason why a call ended.
- NECallType
- Type of call.
- NECamera
- NEDesktopVideoRenderMode
- Preferred desktop video render path used during RTC initialization.
- NENetworkQuality
- network quality
- NERtcVirtualBackgroundSourceStateReason
- Reason for the state of the virtual background feature.
- NIMCallStatus
- Status of a call record from NIM RTC.
- NIMRtcCallStatus
- RtcVirtualBackgroundSourceStateReason
Mixins
Constants
- moduleName → const String