CallManager class

Constructors

CallManager()

Properties

appKey String?
no setter
extraConfig NEExtraConfig?
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept() Future<NEResult>
backCallingPageFormFloatWindow() → void
call(String accountId, NECallType callMediaType, [NECallParams? params]) Future<NEResult>
clearBannerActiveState() → void
清除横幅活跃状态(供 native 横幅交互后调用,防止 secondCallIgnored 误判)
closeCamera() Future<void>
closeMicrophone([bool notify = true]) Future<void>
destroyEngine() → void
enableFloatWindow(bool enable) Future<void>
enableFloatWindowOutOfApp(bool enable) Future<void>
启用/禁用应用外悬浮窗(画中画) 前提:需要先调用 enableFloatWindow(true)
enableIncomingBanner(bool enable) → void
enableVirtualBackground(bool enable) Future<void>
enableWakeLock(bool enable) Future<void>
enterCallingPageFromBanner() → void
从横幅直接进入通话页(不走 setStateEventOnCallReceived,避免 banner 逻辑重入死循环)
handleAppEnterBackground() → void
handleAppEnterForeground() → void
handleBannerAccept() Future<void>
横幅接听按钮被点击(由 iOS 原生通过方法通道回调)
handleBannerReject() Future<void>
横幅拒绝按钮被点击(由 iOS 原生通过方法通道回调)
handleLoginSuccess(String accountId, String token) → void
handleLogoutSuccess() → void
hangup() Future<NEResult>
initAudioPlayDeviceAndCamera() → void
isSamsungDevice() Future<bool>
isScreenLocked() Future<bool>
launchCallingPage() → void
login(String appKey, String accountId, String token, {NECertificateConfig? certificateConfig, NEExtraConfig? extraConfig}) Future<NEResult>
logout() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCamera(NECamera camera, int viewId) Future<NEResult>
openFloatWindow() → void
openFloatWindowWithPageState() Future<void>
openLockScreenApp() → void
openMicrophone([bool notify = true]) Future<NEResult>
pullBackgroundApp() → void
reject() Future<NEResult>
requestFloatPermission() Future<void>
setBlurBackground(bool enable) Future<void>
setCallingBell(String assetName) Future<void>
setIncomingBannerEnabled(bool enable) → void
setSelfInfo(String nickname, String avatar) Future<NEResult>
setSpeakerphoneOn(bool enable) Future<void>
setupEngine(String appKey, String accountId, {NEExtraConfig? extraConfig}) Future<void>
setupLocalView(int viewId) Future<void>
setupRemoteView(String userId, int viewId) Future<void>
showIncomingBanner() → void
showToast(String string) → void
startForegroundService() Future<void>
stopForegroundService() → void
stopRemoteView(String userId) Future<void>
switchCallMediaType(NECallType mediaType, NECallSwitchState state) Future<void>
switchCamera(NECamera camera) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CallManager
no setter