call abstract method
Future<NEResult<NECallInfo> >
call(
- String accId,
- NECallType callType, {
- String? extraInfo,
- String? rtcChannelName,
- String? globalExtraCopy,
- NECallPushConfig? pushConfig,
Places an outgoing call to the specified accId.
The callType determines whether this is an audio or video call.
Optional extraInfo, rtcChannelName, globalExtraCopy and pushConfig
can be used to attach custom metadata and push notification behavior.
Implementation
Future<NEResult<NECallInfo>> call(
String accId,
NECallType callType, {
String? extraInfo,
String? rtcChannelName,
String? globalExtraCopy,
NECallPushConfig? pushConfig,
});