getCallConfig abstract method
Returns the current call configuration, or null if none is set.
Implementation
Future<NECallConfig?> getCallConfig();
Returns the current call configuration, or null if none is set.
Future<NECallConfig?> getCallConfig();