getCallInfo abstract method
Returns information about the current call, or null if there is no call.
Implementation
Future<NECallInfo?> getCallInfo();
Returns information about the current call, or null if there is no call.
Future<NECallInfo?> getCallInfo();