onPlatformViewCreated property

PlatformViewCreatedCallback? onPlatformViewCreated
final

Callback triggered when the underlying render target is created.

On Android, iOS, and macOS the callback receives a platform view id. On Windows it receives the created texture renderer id.

Implementation

final PlatformViewCreatedCallback? onPlatformViewCreated;