S class
Constructors
- S()
Properties
- accept → String
-
acceptno setter - answerOnOtherDevice → String
-
The other client has answered the callno setter - applyForCameraPermission → String
-
apply for camera permissionno setter - applyForMicrophoneAndCameraPermissions → String
-
apply for microphone and camera permissionsno setter - applyForMicrophonePermission → String
-
apply for microphone permissionno setter - blurBackground → String
-
blurBackgroundno setter - callFailedUserIdEmpty → String
-
Call failed, userId is emptyno setter - cameraIsOff → String
-
cameraIsOffno setter - cameraIsOn → String
-
cameraIsOnno setter - displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions → String
-
display popUpWindow while running in the background and display popUpWindow permissionsno setter - errorInPeerBlacklist → String
-
error in peer blacklistno setter - groupCallCameraOff → String
-
Camera Offno setter - groupCallCameraOn → String
-
Camera Onno setter - groupCallConnecting → String
-
Connecting...no setter - groupCallCreateFailed → String
-
Create group call failedno setter - groupCallDuration → String
-
Durationno setter - groupCallEnded → String
-
Group call endedno setter - groupCallIgnore → String
-
Ignoreno setter - groupCallInitFailed → String
-
Group call init failedno setter - groupCallInProgress → String
-
In Callno setter - groupCallInvitation → String
-
Group Call Invitationno setter - groupCallInvite → String
-
Inviteno setter - groupCallInviteMore → String
-
Invite Moreno setter - groupCallInviteYouToJoin → String
-
invites you to join group callno setter - groupCallJoinFailed → String
-
Join group call failedno setter - groupCallJoining → String
-
Joining...no setter - groupCallMemberJoined → String
-
Joinedno setter - groupCallMemberLeft → String
-
Leftno setter - groupCallMembersFull → String
-
Group call is fullno setter - groupCallMicOff → String
-
Mic Offno setter - groupCallMicOn → String
-
Mic Onno setter - groupCallMinimize → String
-
Minimizeno setter - groupCallMuted → String
-
Mutedno setter - groupCallNetworkError → String
-
Network error, please try againno setter - groupCallNoVideo → String
-
Video not enabledno setter - groupCallSpeakerOff → String
-
Speaker Offno setter - groupCallSpeakerOn → String
-
Speaker Onno setter - groupCallSpeaking → String
-
Speakingno setter - groupCallSwitchCamera → String
-
Switch Camerano setter - groupCallToggleCamera → String
-
Camerano setter - groupCallToggleMic → String
-
Microphoneno setter - groupCallToggleSpeaker → String
-
Speakerno setter - groupCallWaiting → String
-
Waitingno setter - hangUp → String
-
hangUpno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- initEngineFail → String
-
Init engine failedno setter - insufficientPermissions → String
-
insufficient permissionsno setter - microphoneIsOff → String
-
microphoneIsOffno setter - microphoneIsOn → String
-
microphoneIsOnno setter - needBackgroundStartPermission → String
-
Your phone has not granted background start permission, minimizing calls may not work properlyno setter - needFloatWindowPermission → String
-
need float window permissionno setter - needToAccessCameraPermission → String
-
need to access camera permissionno setter - needToAccessMicrophoneAndCameraPermissions → String
-
need to access microphone and camera permissionsno setter - needToAccessMicrophonePermission → String
-
need to access microphone permissionno setter - noBackgroundStartPermission → String
-
no background start permissionno setter - noFloatWindowPermission → String
-
no float window permissionno setter - permissionResultFail → String
-
Permission result failno setter - rejectOnOtherDevice → String
-
The other client has rejected the callno setter - remoteCancel → String
-
The call was canceledno setter - remoteTimeout → String
-
Timeout and no responseno setter - remoteUserReject → String
-
remote user rejectedno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speakerIsOff → String
-
speakerIsOffno setter - speakerIsOn → String
-
speakerIsOnno setter - startCameraPermissionDenied → String
-
Start camera permission denied.no setter - switchCamera → String
-
switchCamerano setter - userBusy → String
-
Other party is busyno setter - userInCall → String
-
User is already in a callno setter - waiting → String
-
waitingno setter - youHaveANewCall → String
-
You have a new callno setter
Methods
-
groupCallOtherMembers(
Object count) → String -
and {count} others -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
Locale locale) → Future< S> -
maybeOf(
BuildContext context) → S? -
of(
BuildContext context) → S
Constants
- delegate → const AppLocalizationDelegate