displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions property
String
get
displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions
display popUpWindow while running in the background and display popUpWindow permissions
Implementation
String
get displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions {
return Intl.message(
'display popUpWindow while running in the background and display popUpWindow permissions',
name:
'displayPopUpWindowWhileRunningInTheBackgroundAndDisplayPopUpWindowPermissions',
desc: '',
args: [],
);
}